==> kubernetes-model-1.0.60-sources.jar: io/fabric8/openshift/api/model/SignatureSubjectFluentImpl.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;

public class SignatureSubjectFluentImpl<A extends SignatureSubjectFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements SignatureSubjectFluent<A>{

    private String commonName;
    private String organization;
    private String publicKeyID;

    public SignatureSubjectFluentImpl(){
    }
    public SignatureSubjectFluentImpl(SignatureSubject instance){
            this.withCommonName(instance.getCommonName()); 
            this.withOrganization(instance.getOrganization()); 
            this.withPublicKeyID(instance.getPublicKeyID()); 
    }

    public String getCommonName(){
            return this.commonName;
    }

    public A withCommonName(String commonName){
            this.commonName=commonName; return (A) this;
    }

    public String getOrganization(){
            return this.organization;
    }

    public A withOrganization(String organization){
            this.organization=organization; return (A) this;
    }

    public String getPublicKeyID(){
            return this.publicKeyID;
    }

    public A withPublicKeyID(String publicKeyID){
            this.publicKeyID=publicKeyID; return (A) this;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            SignatureSubjectFluentImpl that = (SignatureSubjectFluentImpl) o;
            if (commonName != null ? !commonName.equals(that.commonName) :that.commonName != null) return false;
            if (organization != null ? !organization.equals(that.organization) :that.organization != null) return false;
            if (publicKeyID != null ? !publicKeyID.equals(that.publicKeyID) :that.publicKeyID != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.61-sources.jar: io/fabric8/openshift/api/model/SignatureSubjectFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.String;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.Object;

public class SignatureSubjectFluentImpl<A extends SignatureSubjectFluent<A>> extends BaseFluent<A> implements SignatureSubjectFluent<A>{

    private String commonName;
    private String organization;
    private String publicKeyID;

    public SignatureSubjectFluentImpl(){
    }
    public SignatureSubjectFluentImpl(SignatureSubject instance){
            this.withCommonName(instance.getCommonName()); 
            this.withOrganization(instance.getOrganization()); 
            this.withPublicKeyID(instance.getPublicKeyID()); 
    }

    public String getCommonName(){
            return this.commonName;
    }

    public A withCommonName(String commonName){
            this.commonName=commonName; return (A) this;
    }

    public String getOrganization(){
            return this.organization;
    }

    public A withOrganization(String organization){
            this.organization=organization; return (A) this;
    }

    public String getPublicKeyID(){
            return this.publicKeyID;
    }

    public A withPublicKeyID(String publicKeyID){
            this.publicKeyID=publicKeyID; return (A) this;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            SignatureSubjectFluentImpl that = (SignatureSubjectFluentImpl) o;
            if (commonName != null ? !commonName.equals(that.commonName) :that.commonName != null) return false;
            if (organization != null ? !organization.equals(that.organization) :that.organization != null) return false;
            if (publicKeyID != null ? !publicKeyID.equals(that.publicKeyID) :that.publicKeyID != null) return false;
            return true;
    }




}
